@@ -3,7 +3,7 @@ BEGIN {
   $Reply::AUTHORITY = 'cpan:DOY';
 }
 {
-  $Reply::VERSION = '0.07';
+  $Reply::VERSION = '0.08';
 }
 use strict;
 use warnings;
@@ -219,7 +219,7 @@ Reply - read, eval, print, loop, yay!
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -321,21 +321,21 @@ You can also look for information at:
 
 =over 4
 
-=item * AnnoCPAN: Annotated CPAN documentation
+=item * MetaCPAN
 
-L<http://annocpan.org/dist/Reply>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Reply>
+L<https://metacpan.org/release/Reply>
 
 =item * RT: CPAN's request tracker
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Reply>
 
-=item * Search CPAN
+=item * Github
 
-L<http://search.cpan.org/dist/Reply>
+L<https://github.com/doy/reply>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/Reply>
 
 =back
 
